@@ -30,6 +30,7 @@ def get_template(
     is_codestarsourceconnection = (
         source.get("Provider", "").lower() == "codestarsourceconnection"
     )
+    is_custom = source.get("Provider", "").lower() == "custom"
     is_s3 = source.get("Provider", "").lower() == "s3"
     description = f"""Bootstrap template used to bring up the main ServiceCatalog-Puppet AWS CodePipeline with dependencies
 {{"version": "{puppet_version}", "framework": "servicecatalog-puppet", "role": "bootstrap-master"}}"""
@@ -524,6 +525,52 @@ def get_template(
             )
         )
 
+    if is_custom:
+        source_stage.Actions.append(
+            codepipeline.Actions(
+                RunOrder=1,
+                ActionTypeId=codepipeline.ActionTypeId(
+                    Category="Source",
+                    Owner="Custom",
+                    Version=source.get("Configuration").get("CustomActionTypeVersion"),
+                    Provider=source.get("Configuration").get(
+                        "CustomActionTypeProvider"
+                    ),
+                ),
+                OutputArtifacts=[codepipeline.OutputArtifacts(Name="Source")],
+                Configuration={
+                    "GitUrl": source.get("Configuration").get("GitUrl"),
+                    "Branch": source.get("Configuration").get("Branch"),
+                    "PipelineName": t.Sub("${AWS::StackName}-pipeline"),
+                },
+                Name="Source",
+            )
+        )
+        webhook = codepipeline.Webhook(
+            "Webhook",
+            Authentication="IP",
+            TargetAction="Source",
+            AuthenticationConfiguration=codepipeline.WebhookAuthConfiguration(
+                AllowedIPRange=source.get("Configuration").get("GitWebHookIpAddress")
+            ),
+            Filters=[
+                codepipeline.WebhookFilterRule(
+                    JsonPath="$.changes[0].ref.id", MatchEquals="refs/heads/{Branch}"
+                )
+            ],
+            TargetPipelineVersion=1,
+            TargetPipeline=t.Sub("${AWS::StackName}-pipeline"),
+        )
+        template.add_resource(webhook)
+        values_for_sub = {
+            "GitUrl": source.get("Configuration").get("GitUrl"),
+            "WebhookUrl": t.GetAtt(webhook, "Url"),
+        }
+        output_to_add = t.Output("WebhookUrl")
+        output_to_add.Value = t.Sub("${GitUrl}||${WebhookUrl}", **values_for_sub)
+        output_to_add.Export = t.Export(t.Sub("${AWS::StackName}-pipeline"))
+        template.add_output(output_to_add)
+
     if is_codestarsourceconnection:
         source_stage.Actions.append(
             codepipeline.Actions(
